SystemOrganization addCategory: #'Pier-Tests-Wysiwyg'!

JSJasmineBaseTestRunner subclass: #PRTestWysiwgEditorParser
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Tests-Wysiwyg'!

!PRTestWysiwgEditorParser commentStamp: 'NickAger 7/12/2011 19:46' prior: 0!
PRTestWysiwgEditorParser is derived from JSJasmineBaseTestRunner, which is checked into:
 * repository: http://www.squeaksource.com/Seaside30Addons
 * package: Javascript-Jasmine!

!PRTestWysiwgEditorParser class methodsFor: 'class initialization' stamp: 'NickAger 7/12/2011 19:38'!
initialize
	| application |
	application := WAAdmin register: self asApplicationAt: 'testwysiwgParser'.
	
	"need to use JQScriptGenerator as the default generator (WADefaultScriptGenerator) adds an onload handler to the body tag,
	which the overrides the onload used by the test runner"
	application preferenceAt: #scriptGeneratorClass put: JQScriptGenerator.! !

!PRTestWysiwgEditorParser methodsFor: 'tests' stamp: 'NickAger 7/12/2011 19:49'!
testsToRun
	^ '
describe("Parser", function() {
	beforeEach(function() {
		this.addMatchers({
			shouldParseInto: function(expectedWikiOuput) {
      			var newDiv = document.createElement("div");
      			newDiv.innerHTML = this.actual;
				var parsedResult = parseHtmlToPierWikiSyntax (newDiv);
				return parsedResult == expectedWikiOuput;
			}
		});
	});

	it("should be able to translate annotated paragraphs", function() {
		expect("<p class=''annotated note''>a note</p>").shouldParseInto("@@note a note\n");
	});


	it("should be able to translate normal paragraphs", function() {
		expect("<p>a paragraph</p>").shouldParseInto("a paragraph\n");
	});
	
	it("should be able to translate unordered lists", function() {
		expect("<ul><li>bullet 1</li><li>bullet 2</li></ul>").shouldParseInto("- bullet 1\n- bullet 2\n");
	});
	
	it("should be able to translate ordered lists", function() {
		expect("<ol><li>item 1</li><li>item 2</li></ol>").shouldParseInto("# item 1\n# item 2\n");
	});
	
	it("should be able to translate lists when surrounded by spurious inline markup", function() {
		expect("<b><ol><li>item 1</li><li>item 2</li></ol></b>").shouldParseInto("# item 1\n# item 2\n");
	});
	
	it("should be able to translate bold", function() {
		expect("<b>bold</b>").shouldParseInto("\"\"bold\"\"");
	});
	
	it("should be able to translate strong", function() {
		expect("<strong>strong</strong>").shouldParseInto("\"\"strong\"\"");
	});
	
	it("should be able to translate italic", function() {
		expect("<i>italic</i>").shouldParseInto("''''italic''''");
	});
	
	it("should be able to translate emphasized", function() {
		expect("<em>emphasized</em>").shouldParseInto("''''emphasized''''");
	});
	
	it("should be able to translate inserted", function() {
		expect("<ins>inserted</ins>").shouldParseInto("__inserted__");
	});
	
	it("should be able to translate underlined", function() {
		expect("<u>underlined</u>").shouldParseInto("__underlined__");
	});
	
	it("should be able to translate deleted", function() {
		expect("<del>deleted</del>").shouldParseInto("--deleted--");
	});
	
	it("should be able to translate code", function() {
		expect("<code>code</code>").shouldParseInto("==code==");
	});
	
	it("should be able to translate subscript", function() {
		expect("<sub>subscript</sub>").shouldParseInto("@@subscript@@");
	});
	
	it("should be able to translate superscript", function() {
		expect("<sup>superscript</sup>").shouldParseInto("^^superscript^^");
	});
	
	it("should be able to ignore spans", function() {
		expect("<span>ignore span</span>").shouldParseInto("ignore span");
	});
	
	it("should be able to ignore divs", function() {
		expect("<div>ignore div</div>").shouldParseInto("ignore div\n");
	});
	
	it("should be able to translate anchors", function() {
		expect("<a href=\"http://getitmade.com\" title=\"http://www.getitmade.com\">crowd fund your ideas</a>").shouldParseInto("*crowd fund your ideas>http://www.getitmade.com*");
	});
	
	it("should be able to translate links to emails", function() {
		expect("<a href=\"mailto:nick.ager@gmail.com\" title=\"nick.ager@gmail.com\">mail me</a>").shouldParseInto("*mail me>nick.ager@gmail.com*");
	});

	it("should be able to translate h1", function() {
		expect("<h1>heading</h1>").shouldParseInto("!!heading\n");
	});

	it("should be able to translate h2", function() {
		expect("<h2>heading</h2>").shouldParseInto("!!!!heading\n");
	});

	it("should be able to translate h3", function() {
		expect("<h3>heading</h3>").shouldParseInto("!!!!!!heading\n");
	});

	it("should be able to translate h4", function() {
		expect("<h4>heading</h4>").shouldParseInto("!!!!!!!!heading\n");
	});

	it("should be able to translate h5", function() {
		expect("<h5>heading</h5>").shouldParseInto("!!!!!!!!!!heading\n");
	});				

	it("should be able to translate h6", function() {
		expect("<h6>heading</h6>").shouldParseInto("!!!!!!!!!!!!heading\n");
	});	
		
	it("should be able to translate horizontal line", function() {
		expect("<hr>").shouldParseInto("_\n");
	});		
			
	it("should be able to translate line break", function() {
		expect("<br>").shouldParseInto("\n");
	});	
		
	it("should be able to translate a definition list", function() {
		expect("<dl><dt>word</dt><dd>a definition</dd></dl>").shouldParseInto(";word\n:a definition\n");
	});	
		
	it("should be able to translate preformatted", function() {
		expect("<pre>line 1\nline 2</pre>").shouldParseInto("=line 1\n=line 2\n");
	});				

});
' withInternetLineEndings! !

!PRTestWysiwgEditorParser methodsFor: 'updating' stamp: 'NickAger 7/12/2011 19:38'!
updateRoot: anHtmlRoot
	anHtmlRoot javascript url: PRWysiwygFileLibrary / #parseHtmlToPierWikiSyntaxJs.			
	super updateRoot: anHtmlRoot.! !
PRTestWysiwgEditorParser initialize!
